pub struct StreamingResponse<T> { /* private fields */ }Expand description
A streaming gRPC response.
Compared to the normal streaming response type from tonic, StreamingResponse handles a special case where
servers may not send a guaranteed initial message, which is required for tonic to create and return the
Streaming object that can then be polled. This leads to an issue where calls can effectively appear to block
until the first message is sent by the server, which is suboptimal.
StreamingResponse exposes a unified Stream implementation that encompasses both the initial RPC
establishment and subsequent messages sent by the server, to allow for a more seamless experience when working
with streaming RPCs.